==> jc-1.4.0.tar.gz: gnu/java/rmi/RMIMarshalledObjectOutputStream.h <==
// public class gnu.java.rmi.RMIMarshalledObjectOutputStream

// class file dependencies
// @dep_class 1f899a31d60867f8 gnu_java_rmi_RMIMarshalledObjectOutputStream
// @dep_class e5e2d45597aa8e22 gnu_java_rmi_server_RMIObjectOutputStream
// @dep_class adac05c7137ad26e java_io_ObjectOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_rmi_server_RMIObjectOutputStream

#include "gnu/java/rmi/server/RMIObjectOutputStream.h"

#ifndef _JC_gnu_java_rmi_RMIMarshalledObjectOutputStream_H_
#define _JC_gnu_java_rmi_RMIMarshalledObjectOutputStream_H_

// Forward structure declarations
struct _jc_java_io_ByteArrayOutputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object;

typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *);
extern _jc_byte_array *_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$getLocBytes$8238dcc8481b2a23(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *);
extern void _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$setAnnotation$95da01025bf29727(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method_info$getLocBytes$8238dcc8481b2a23;
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method_info$setAnnotation$95da01025bf29727;

// Virtual methods structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *);
	_jc_byte_array	*(*getLocBytes$8238dcc8481b2a23)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *);
	void	(*setAnnotation$95da01025bf29727)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_ObjectOutputStream$vmethods	java_io_ObjectOutputStream;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods	gnu_java_rmi_server_RMIObjectOutputStream;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods	gnu_java_rmi_RMIMarshalledObjectOutputStream;
};

// Vtype
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs {
	struct _jc_java_io_ObjectOutputStream$object	*locStream;
	struct _jc_java_io_ByteArrayOutputStream$object	*locBytesStream;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs {
    _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs	gnu_java_rmi_RMIMarshalledObjectOutputStream;
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs	gnu_java_rmi_server_RMIObjectOutputStream;
    _jc_java_io_ObjectOutputStream$sub_refs	java_io_ObjectOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_ObjectOutputStream$sub_nonrefs	java_io_ObjectOutputStream;
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectOutputStream;
    _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs	gnu_java_rmi_RMIMarshalledObjectOutputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object {
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype	*vtype;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_RMIMarshalledObjectOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$class_object;

#endif	/* _JC_gnu_java_rmi_RMIMarshalledObjectOutputStream_H_ */

==> jc-1.4.5.tar.gz: gnu/java/rmi/RMIMarshalledObjectOutputStream.h <==
// public class gnu.java.rmi.RMIMarshalledObjectOutputStream

// class file dependencies
// @dep_class 1f899a31d60867f8 gnu_java_rmi_RMIMarshalledObjectOutputStream
// @dep_class e5e2d45597aa8e22 gnu_java_rmi_server_RMIObjectOutputStream
// @dep_class adac05c7137ad26e java_io_ObjectOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_rmi_server_RMIObjectOutputStream

#include "gnu/java/rmi/server/RMIObjectOutputStream.h"

#ifndef _JC_gnu_java_rmi_RMIMarshalledObjectOutputStream_H_
#define _JC_gnu_java_rmi_RMIMarshalledObjectOutputStream_H_

// Forward structure declarations
struct _jc_java_io_ByteArrayOutputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object;

typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$getLocBytes$8238dcc8481b2a23(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method$setAnnotation$95da01025bf29727(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method_info$getLocBytes$8238dcc8481b2a23;
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$method_info$setAnnotation$95da01025bf29727;

// Virtual methods structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getLocBytes$8238dcc8481b2a23)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *) _JC_JCNI_ATTR;
	void	(*setAnnotation$95da01025bf29727)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_ObjectOutputStream$vmethods	java_io_ObjectOutputStream;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods	gnu_java_rmi_server_RMIObjectOutputStream;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vmethods	gnu_java_rmi_RMIMarshalledObjectOutputStream;
};

// Vtype
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs {
	struct _jc_java_io_ObjectOutputStream$object	*locStream;
	struct _jc_java_io_ByteArrayOutputStream$object	*locBytesStream;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs {
    _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_refs	gnu_java_rmi_RMIMarshalledObjectOutputStream;
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs	gnu_java_rmi_server_RMIObjectOutputStream;
    _jc_java_io_ObjectOutputStream$sub_refs	java_io_ObjectOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_ObjectOutputStream$sub_nonrefs	java_io_ObjectOutputStream;
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectOutputStream;
    _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$sub_nonrefs	gnu_java_rmi_RMIMarshalledObjectOutputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$object {
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype	*vtype;
	_jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$vtype _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_RMIMarshalledObjectOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_RMIMarshalledObjectOutputStream$class_object;

#endif	/* _JC_gnu_java_rmi_RMIMarshalledObjectOutputStream_H_ */
